@@ -20,6 +20,16 @@ class TestMenu:
         menu.add_function_item("title1", lambda x: len(x), {"x": "testparam"})
         assert len(menu.menu_items) == 1
 
+    def test_add_divider(self):
+        menu = micromenu.Menu(
+            "test", "test messsage top", "test message bottom", min_width=20
+        )
+        assert len(menu.menu_items) == 0
+        menu.add_function_item("title1", lambda x: len(x), {"x": "testparam"})
+        menu.add_divider()
+        menu.add_function_item("title2", lambda x: len(x), {"x": "testparam"})
+        assert len(menu.menu_items) == 3
+
     def test_add_message_bottom_item_no_init(self):
         menu = micromenu.Menu("test", "test messsage top", min_width=20)
         assert len(menu.menu_items) == 0
@@ -38,14 +48,13 @@ class TestMenu:
     def test_print_menu(self, capsys):
         menu = micromenu.Menu("test", "test messsage top", "test message bottom")
         menu.add_function_item("title1", lambda x: len(x), {"x": "testparam"})
+        menu.add_divider()
+        menu.add_function_item("title2", lambda x: len(x), {"x": "testparam"})
         menu.print_menu()
         captured = capsys.readouterr()
         assert captured.out.startswith("╭─── test ")
 
     def test_inputs(self):
-        with pytest.raises(ValueError) as excinfo:
-            menu = micromenu.Menu("")
-
         menu = micromenu.Menu("test_title", "")
         assert isinstance(menu, micromenu.Menu)
 
@@ -99,14 +108,16 @@ class TestMenu:
         test_item_indexes(10)
         test_item_indexes(11)
 
-    def test_invalid_input(self, capsys):
+    def test_string_uid_input(self, capsys):
         menu = micromenu.Menu("test", "test messsage top", "test message bottom")
-        menu.add_function_item("title1", lambda x: len(x), {"x": "testparam"})
+        menu.add_function_item(
+            "title1", lambda x: print(x), {"x": "testparam"}, uid="xxx"
+        )
 
-        with patch("sys.stdin", StringIO("a\n0")):
+        with patch("sys.stdin", StringIO("xxx\n0\n")):
             menu.show()
-        captured = capsys.readouterr()
-        assert "Incorrect input, try again." in captured.out
+            captured = capsys.readouterr()
+            assert "testparam" in captured.out
 
     def test_menu_item_out_of_range(self, capsys):
         menu = micromenu.Menu("test", "test messsage top", "test message bottom")
@@ -114,8 +125,8 @@ class TestMenu:
 
         with patch("sys.stdin", StringIO("9\n0")):
             menu.show()
-        captured = capsys.readouterr()
-        assert "Choose a valid item." in captured.out
+            captured = capsys.readouterr()
+            assert "Invalid number, please try again." in captured.out
 
     def test_menu_item_function_called(self, capsys):
         dummy = MagicMock()
